#
# spec file for package ptpd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ptpd
Version:        2.3.1
Release:        10.3
Summary:        Implementation of the Precision Time protocol (IEEE 1588)
License:        BSD-3-Clause
Group:          System/Daemons
URL:            https://github.com/ptpd/ptpd
Source0:        https://github.com/ptpd/ptpd/archive/ptpd-%{version}.tar.gz
Source1:        ptpd2.service
Source3:        conf.sysconfig.ptpd
# PATCH-FIX-UPSTREAM ptpd2-net-snmp_U64.patch gh#ptpd/ptpd#25
Patch0:         ptpd2-net-snmp_U64.patch
# PATCH-FIX-UPSTREAM resolve EVP_MD_CTX name conflict
Patch1:         ptpd-evp-md-ctx.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  net-snmp-devel
BuildRequires:  openssl-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  zlib-devel
%{?systemd_requires}

%description
The PTP daemon (PTPd) implements the Precision Time protocol (PTP) as
defined by the IEEE 1588 standard. PTP was developed to provide very
precise time coordination of LAN connected computers.

PTPd is a complete implementation of the IEEE 1588 specification for a
standard (non-boundary) clock. PTPd has been tested with and is known
to work properly with other IEEE 1588 implementations.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch -P 0
%patch -P 1 -p1

%build
autoreconf -fiv
%configure \
  --enable-statistics \
  --enable-experimental-options
make %{?_smp_mflags}

%install
%make_install
install -Dpm 0644 %{SOURCE1} \
  %{buildroot}/%{_unitdir}/%{name}2.service
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}2
# Generate default config
install -d %{buildroot}%{_sysconfdir}
./src/ptpd2 --default-config > %{buildroot}%{_sysconfdir}/%{name}2.conf
install -Dpm 0644 %{SOURCE3} \
  %{buildroot}%{_fillupdir}/sysconfig.ptpd2
# have to create the below, else ptpd will not log drift
install -d %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/ptpd2_kernelclock.drift

%pre
%service_add_pre %{name}2.service

%preun
%service_del_preun %{name}2.service

%post
%service_add_post %{name}2.service
%{fillup_only -n ptpd2}

%postun
%service_del_postun %{name}2.service

%files
%license COPYRIGHT
%doc ChangeLog README
%config(noreplace) %{_sysconfdir}/%{name}2.conf
%{_sbindir}/ptpd2
%{_sbindir}/rcptpd2
%{_mandir}/man5/ptpd2.conf.5%{?ext_man}
%{_mandir}/man8/ptpd2.8%{?ext_man}
%{_datadir}/ptpd
%{_unitdir}/ptpd2.service
%{_fillupdir}/*
%config %ghost %{_localstatedir}/log/ptpd2_kernelclock.drift

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Oct 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * ptpd2.service
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_unitdir instead of %%{_libexecdir}/systemd/system in the
  %%files section.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Trim redundant metadata from the description. Use noun phrase
  for the summary.
* Wed Nov 21 2018 iulhaq@suse.com
- Fix name conflict with openssl variable
  * ptpd-evp-md-ctx.patch
* Fri Nov  9 2018 Martin Pluskal <mpluskal@suse.com>
- Enable experimental features
* Thu Mar  8 2018 mpluskal@suse.com
- Generate default config during build
* Thu Jan 25 2018 mpluskal@suse.com
- Use correct executable path in service file (bsc#1076900)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Jul 13 2016 mpluskal@suse.com
- Fix building with latest net-snmp
  * ptpd2-net-snmp_U64.patch
* Thu May 12 2016 mpluskal@suse.com
- Update to 2.3.1
  * see attached Changelog for full list of changes
- Update project and download url
- Small spec file cleanups
* Mon Jun  1 2015 mpluskal@suse.com
- Update to 2.3.0
  * see attached Changelog for full list of changes
- Add systemd unit file and config file
  * ptpd2.conf
  * ptpd2.service
- Drop init file
  * conf.ptpd.init
- Cleanup spec file with spec-clener
* Thu Oct 27 2011 coolo@suse.com
- use original tar
- do not mention runlevel 4
- don't depend on octave for documentation
- remove unused patches
* Mon May  9 2011 dbahi@novell.com
- update to release 1.1.0 (2010-10-12)
  * Add code to limit how much of an offset or delay the client is
    willing to tolerate.
  * Add support for BINTIME on FreeBSD which gives more accurate
    packet timestamps.
  * Add quality file support
  * Add support for syslog.
  * Add support for user configurable TTL.
  * Clean up code formatting, headers, comments etc.
* Mon Oct 19 2009 alext@suse.de
- Update to ptpd git snapshot of 599b03b post 1.0.0. release, includes
  patches by Patrick Ohly from the ptpd git repo as follows:
  599b03b... added basic compilation instructions
  ef2a5cc... Linux HW time stamping: define fallbacks no longer in net_tstamp.h,
    need them in user space to compile
  f837c84... netShutdown(): check whether it is called during init and avoid
    SIOCSHWTSTAMP with invalid eventSock
  70181a1... Linux: use generic net_tstamp API for more accurate time stamping,
    with and without HW support
  e003660... Merge branch 'ptpd-1.0.0-cluster-clock'
  c6eb9c8... timertest: ping-pong test which measures clock skew between nodes
  9275c8d... adjtimex call: added error checking
  03085e7... use ajdtimex() tick adjustment to increase range of total clock
    adjustment
  576ffbf... fixed and extended printing of statistics
  dc61251... include time in initialization of random seed for delay requests:
    otherwise different runs use the same intervals
  c380fa7... allow much higher frequency adjustments
  7523072... added implementation of E1000 NIC time control
  96beda4... optionally set PTP_ASSIST in msgPackDelayReq()
  7ad1b32... *always* set PTP_ASSIST in Sync message
  3444e67... configuration file for doxygen
  864a492... separated system time and time which is controlled/used by PTP
  - added Doxygen-style comments
  - time.c accesses PTP time (currently always uses system time)
  - timer.c controls delays in the host's system time (as before)
  - moved nanoSleep() to be consistent
  3762491... added the possibility to log into system log: use -f syslog
  b8e2d39... fix ubild on freebsd
* Fri Jun 12 2009 coolo@novell.com
- fix build with glibc 2.10
* Tue Nov 11 2008 dbahi@suse.de
- modified to use 1.0.0 release instead of rc
* Wed Nov  7 2007 dbahi@suse.de
- cleaned up init script and install process
* Fri Nov  2 2007 dbahi@suse.de
- patch makefile to allow env CFLAGS
- adjusted sysconfig to use %%fill_only
* Fri Nov  2 2007 dbahi@suse.de
- added system v init script and sysconfig file suitable
  for use with yast /etc/sysconfig editor
* Tue Oct 23 2007 dbahi@suse.de
- initial package creation
